-- 既存のビューとテーブルの削除
DROP VIEW IF EXISTS bookview;
DROP TABLE IF EXISTS book;
DROP TABLE IF EXISTS author;


-- author（著者）テーブルの作成
CREATE TABLE author
(
	-- 著者のID
	authorid varchar(10) NOT NULL UNIQUE COMMENT '著者のID',
	-- 著者の名前
	authorname varchar(30),
	PRIMARY KEY (authorid)
)DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;


-- book（書籍）テーブルの作成
CREATE TABLE book
(
	-- 本のID
	id varchar(10) NOT NULL UNIQUE COMMENT '本のID',
	-- 本の名前
	name varchar(30) COMMENT '本の名前',
	-- 本の価格
	price int COMMENT '本の価格',
	-- 著者のID
	authorid varchar(10) NOT NULL COMMENT '著者のID',
	PRIMARY KEY (id)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;



-- 外部キーの設定
ALTER TABLE book
	ADD FOREIGN KEY (authorid)
	REFERENCES author (authorid)
	ON UPDATE RESTRICT
	ON DELETE RESTRICT
;


-- ビューの作成
CREATE VIEW bookview AS select book.id, book.name, book.price, author.authorname from book,author where book.authorid = author.authorid;

-- 著者テーブルへのデータ登録
INSERT INTO author (authorid, authorname) VALUES ('a001', '野村太郎');
INSERT INTO author (authorid, authorname) VALUES ('a002', 'みずほ花子');

-- 書籍テーブルへのデータ登録
INSERT INTO book (id, name, price, authorid) VALUES ('b001', 'はじめてのJava', '1900', 'a001');
INSERT INTO book (id, name, price, authorid) VALUES ('b002', '楽しく学ぼうC#', '2500', 'a002');
INSERT INTO book (id, name, price, authorid) VALUES ('b003', 'クラウド全集', '3000', 'a001');


